@@ -85,6 +85,10 @@ GeoIP_GeoIP_init(PyObject *self, PyObject *args, PyObject *kwargs)
         return -1;
     }
 
+#if PY_MAJOR_VERSION >= 3
+    GeoIP_set_charset(GeoIP->gi, GEOIP_CHARSET_UTF8);
+#endif
+
     return 0;
 }
 
@@ -500,6 +504,7 @@ static PyObject *GeoIP_range_by_ip_Py(PyObject * self, PyObject * args)
 static PyObject *GeoIP_charset_Py(PyObject *self, PyObject *UNUSED(args))
 {
     GeoIP_GeoIPObject *GeoIP = (GeoIP_GeoIPObject *)self;
+
     return Py_BuildValue("i", GeoIP_charset(GeoIP->gi));
 }
 
@@ -510,8 +515,14 @@ static PyObject *GeoIP_set_charset_Py(PyObject * self, PyObject * args)
     if (!PyArg_ParseTuple(args, "i", &charset)) {
         return NULL;
     }
+#if PY_MAJOR_VERSION >= 3
+    if (charset != GEOIP_CHARSET_UTF8) {
+        PyErr_SetString(PyExc_ValueError,
+                        "Only UTF-8 is supported for Python 3+.");
+        return NULL;
+    }
+#endif
     return Py_BuildValue("i", GeoIP_set_charset(GeoIP->gi, charset));
-
 }
 
 static PyObject *GeoIP_last_netmask_Py(PyObject * self, PyObject *UNUSED(args))
